@@ -171,6 +171,115 @@ class CacheDatabaseColumns(enum.Enum):
     TRIGGERED_AFTER_CANDLES_CLOSE = "triggered_after_candles_close"
 
 
+class PlotAttributes(enum.Enum):
+    KIND = "kind"
+    X = "x"
+    Y = "y"
+    OPEN = "open"
+    HIGH = "high"
+    LOW = "low"
+    CLOSE = "close"
+    VOLUME = "volume"
+    TITLE = "title"
+    TEXT = "text"
+    SUB_ELEMENTS = "sub_elements"
+    ELEMENTS = "elements"
+    NAME = "name"
+    DATA = "data"
+    X_TYPE = "x_type"
+    Y_TYPE = "y_type"
+    MODE = "mode"
+    LINE_SHAPE = "line_shape"
+    OWN_XAXIS = "own_xaxis"
+    OWN_YAXIS = "own_yaxis"
+    SIDE = "side"
+    VALUE = "value"
+    CONFIG = "config"
+    SCHEMA = "schema"
+    TENTACLE = "tentacle"
+    TENTACLE_TYPE = "tentacle_type"
+    COLUMNS = "columns"
+    ROWS = "rows"
+    SEARCHES = "searches"
+    IS_HIDDEN = "is_hidden"
+    TYPE = "type"
+    COLOR = "color"
+    HTML = "html"
+    SIZE = "size"
+    SYMBOL = "symbol"
+
+
+class BacktestingMetadata(enum.Enum):
+    ID = "id"
+    GAINS = "gains"
+    PERCENT_GAINS = "% gains"
+    END_PORTFOLIO = "end portfolio"
+    START_PORTFOLIO = "start portfolio"
+    WIN_RATE = "% win rate"
+    DRAW_DOWN = "% draw down"
+    COEFFICIENT_OF_DETERMINATION_MAX_BALANCE = "R² max balance"
+    COEFFICIENT_OF_DETERMINATION_END_BALANCE = "R² end balance"
+    SYMBOLS = "symbols"
+    TIME_FRAMES = "time frames"
+    START_TIME = "start time"
+    END_TIME = "end time"
+    DURATION = "duration"
+    ENTRIES = "entries"
+    WINS = "wins"
+    LOSES = "loses"
+    TRADES = "trades"
+    TIMESTAMP = "timestamp"
+    NAME = "name"
+    LEVERAGE = "leverage"
+    OPTIMIZATION_CAMPAIGN = "optimization campaign"
+    USER_INPUTS = "user inputs"
+    BACKTESTING_FILES = "backtesting files"
+    CHILDREN = "children"
+    OPTIMIZER_ID = "optimizer id"
+    EXCHANGE = "exchange"
+
+
+class DBRows(enum.Enum):
+    REFERENCE_MARKET = "ref_market"
+    EXCHANGE = "exchange"
+    EXCHANGES = "exchanges"
+    FUTURE_CONTRACTS = "future_contracts"
+    PAIR = "pair"
+    TIME_FRAME = "time_frame"
+    VALUE = "value"
+    START_TIME = "start_time"
+    END_TIME = "end_time"
+    TRADING_TYPE = "trading_type"
+    SYMBOLS = "symbols"
+
+
+class PlotCharts(enum.Enum):
+    MAIN_CHART = "main-chart"
+    SUB_CHART = "sub-chart"
+
+
+class DisplayedElementTypes(enum.Enum):
+    CHART = "chart"
+    INPUT = "input"
+    TABLE = "table"
+    VALUE = "value"
+
+
+class DBTables(enum.Enum):
+    METADATA = "metadata"
+    INPUTS = "inputs"
+    PORTFOLIO = "portfolio"
+    ORDERS = "all_orders"
+    TRADES = "all_trades"
+    TRANSACTIONS = "all_transactions"
+    CANDLES = "candles"
+    CANDLES_SOURCE = "candles_source"
+    CACHE_SOURCE = "cache_source"
+    SYMBOL = "symbol"
+    FEES_AMOUNT = "fees_amount"
+    FEES_CURRENCY = "fees_currency"
+
+
 class ActivationTopics(enum.Enum):
     """
     Events that can trigger actions
@@ -179,7 +288,7 @@ class ActivationTopics(enum.Enum):
     FULL_CANDLES = "once per bar close"
     IN_CONSTRUCTION_CANDLES = "once per second (Live Price)"
     RECENT_TRADES = "recent trades"
-    EVALUATORS = "after evaluators"
+    EVALUATION_CYCLE = "after evaluators"
 
 
 class DataBaseOrderBy(enum.Enum):
